==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkLight.java <==
// java wrapper for vtkLight object
//

package vtk;
import vtk.*;

public class vtkLight extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long ShallowClone_2();
  public vtkLight ShallowClone() {
    long temp = ShallowClone_2();

    if (temp == 0) return null;
    return (vtkLight)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void Render_3(vtkRenderer id0,int id1);
  public void Render(vtkRenderer id0,int id1)
    { Render_3(id0,id1); }

  private native void SetAmbientColor_4(double id0,double id1,double id2);
  public void SetAmbientColor(double id0,double id1,double id2)
    { SetAmbientColor_4(id0,id1,id2); }

  private native void SetAmbientColor_5(double id0[]);
  public void SetAmbientColor(double id0[])
    { SetAmbientColor_5(id0); }

  private native double[] GetAmbientColor_6();
  public double[] GetAmbientColor()
    { return GetAmbientColor_6(); }

  private native void SetDiffuseColor_7(double id0,double id1,double id2);
  public void SetDiffuseColor(double id0,double id1,double id2)
    { SetDiffuseColor_7(id0,id1,id2); }

  private native void SetDiffuseColor_8(double id0[]);
  public void SetDiffuseColor(double id0[])
    { SetDiffuseColor_8(id0); }

  private native double[] GetDiffuseColor_9();
  public double[] GetDiffuseColor()
    { return GetDiffuseColor_9(); }

  private native void SetSpecularColor_10(double id0,double id1,double id2);
  public void SetSpecularColor(double id0,double id1,double id2)
    { SetSpecularColor_10(id0,id1,id2); }

  private native void SetSpecularColor_11(double id0[]);
  public void SetSpecularColor(double id0[])
    { SetSpecularColor_11(id0); }

  private native double[] GetSpecularColor_12();
  public double[] GetSpecularColor()
    { return GetSpecularColor_12(); }

  private native void SetColor_13(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_13(id0,id1,id2); }

  private native void SetColor_14(double id0[]);
  public void SetColor(double id0[])
    { SetColor_14(id0); }

  private native void SetPosition_15(double id0,double id1,double id2);
  public void SetPosition(double id0,double id1,double id2)
    { SetPosition_15(id0,id1,id2); }

  private native void SetPosition_16(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_16(id0); }

  private native double[] GetPosition_17();
  public double[] GetPosition()
    { return GetPosition_17(); }

  private native void SetFocalPoint_18(double id0,double id1,double id2);
  public void SetFocalPoint(double id0,double id1,double id2)
    { SetFocalPoint_18(id0,id1,id2); }

  private native void SetFocalPoint_19(double id0[]);
  public void SetFocalPoint(double id0[])
    { SetFocalPoint_19(id0); }

  private native double[] GetFocalPoint_20();
  public double[] GetFocalPoint()
    { return GetFocalPoint_20(); }

  private native void SetIntensity_21(double id0);
  public void SetIntensity(double id0)
    { SetIntensity_21(id0); }

  private native double GetIntensity_22();
  public double GetIntensity()
    { return GetIntensity_22(); }

  private native void SetSwitch_23(int id0);
  public void SetSwitch(int id0)
    { SetSwitch_23(id0); }

  private native int GetSwitch_24();
  public int GetSwitch()
    { return GetSwitch_24(); }

  private native void SwitchOn_25();
  public void SwitchOn()
    { SwitchOn_25(); }

  private native void SwitchOff_26();
  public void SwitchOff()
    { SwitchOff_26(); }

  private native void SetPositional_27(int id0);
  public void SetPositional(int id0)
    { SetPositional_27(id0); }

  private native int GetPositional_28();
  public int GetPositional()
    { return GetPositional_28(); }

  private native void PositionalOn_29();
  public void PositionalOn()
    { PositionalOn_29(); }

  private native void PositionalOff_30();
  public void PositionalOff()
    { PositionalOff_30(); }

  private native void SetExponent_31(double id0);
  public void SetExponent(double id0)
    { SetExponent_31(id0); }

  private native double GetExponentMinValue_32();
  public double GetExponentMinValue()
    { return GetExponentMinValue_32(); }

  private native double GetExponentMaxValue_33();
  public double GetExponentMaxValue()
    { return GetExponentMaxValue_33(); }

  private native double GetExponent_34();
  public double GetExponent()
    { return GetExponent_34(); }

  private native void SetConeAngle_35(double id0);
  public void SetConeAngle(double id0)
    { SetConeAngle_35(id0); }

  private native double GetConeAngle_36();
  public double GetConeAngle()
    { return GetConeAngle_36(); }

  private native void SetAttenuationValues_37(double id0,double id1,double id2);
  public void SetAttenuationValues(double id0,double id1,double id2)
    { SetAttenuationValues_37(id0,id1,id2); }

  private native void SetAttenuationValues_38(double id0[]);
  public void SetAttenuationValues(double id0[])
    { SetAttenuationValues_38(id0); }

  private native double[] GetAttenuationValues_39();
  public double[] GetAttenuationValues()
    { return GetAttenuationValues_39(); }

  private native void SetTransformMatrix_40(vtkMatrix4x4 id0);
  public void SetTransformMatrix(vtkMatrix4x4 id0)
    { SetTransformMatrix_40(id0); }

  private native long GetTransformMatrix_41();
  public vtkMatrix4x4 GetTransformMatrix() {
    long temp = GetTransformMatrix_41();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetTransformedPosition_42(double id0[]);
  public void GetTransformedPosition(double id0[])
    { GetTransformedPosition_42(id0); }

  private native double[] GetTransformedPosition_43();
  public double[] GetTransformedPosition()
    { return GetTransformedPosition_43(); }

  private native void GetTransformedFocalPoint_44(double id0[]);
  public void GetTransformedFocalPoint(double id0[])
    { GetTransformedFocalPoint_44(id0); }

  private native double[] GetTransformedFocalPoint_45();
  public double[] GetTransformedFocalPoint()
    { return GetTransformedFocalPoint_45(); }

  private native void SetDirectionAngle_46(double id0,double id1);
  public void SetDirectionAngle(double id0,double id1)
    { SetDirectionAngle_46(id0,id1); }

  private native void SetDirectionAngle_47(double id0[]);
  public void SetDirectionAngle(double id0[])
    { SetDirectionAngle_47(id0); }

  private native void DeepCopy_48(vtkLight id0);
  public void DeepCopy(vtkLight id0)
    { DeepCopy_48(id0); }

  private native void SetLightType_49(int id0);
  public void SetLightType(int id0)
    { SetLightType_49(id0); }

  private native int GetLightType_50();
  public int GetLightType()
    { return GetLightType_50(); }

  private native void SetLightTypeToHeadlight_51();
  public void SetLightTypeToHeadlight()
    { SetLightTypeToHeadlight_51(); }

  private native void SetLightTypeToSceneLight_52();
  public void SetLightTypeToSceneLight()
    { SetLightTypeToSceneLight_52(); }

  private native void SetLightTypeToCameraLight_53();
  public void SetLightTypeToCameraLight()
    { SetLightTypeToCameraLight_53(); }

  private native int LightTypeIsHeadlight_54();
  public int LightTypeIsHeadlight()
    { return LightTypeIsHeadlight_54(); }

  private native int LightTypeIsSceneLight_55();
  public int LightTypeIsSceneLight()
    { return LightTypeIsSceneLight_55(); }

  private native int LightTypeIsCameraLight_56();
  public int LightTypeIsCameraLight()
    { return LightTypeIsCameraLight_56(); }

  public vtkLight() { super(); }

  public vtkLight(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkLight.java <==
// java wrapper for vtkLight object
//

package vtk;
import vtk.*;

public class vtkLight extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long ShallowClone_2();
  public vtkLight ShallowClone() {
    long temp = ShallowClone_2();

    if (temp == 0) return null;
    return (vtkLight)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Render_3(vtkRenderer id0,int id1);
  public void Render(vtkRenderer id0,int id1)
    { Render_3(id0,id1); }

  private native void SetAmbientColor_4(double id0,double id1,double id2);
  public void SetAmbientColor(double id0,double id1,double id2)
    { SetAmbientColor_4(id0,id1,id2); }

  private native void SetAmbientColor_5(double id0[]);
  public void SetAmbientColor(double id0[])
    { SetAmbientColor_5(id0); }

  private native double[] GetAmbientColor_6();
  public double[] GetAmbientColor()
    { return GetAmbientColor_6(); }

  private native void SetDiffuseColor_7(double id0,double id1,double id2);
  public void SetDiffuseColor(double id0,double id1,double id2)
    { SetDiffuseColor_7(id0,id1,id2); }

  private native void SetDiffuseColor_8(double id0[]);
  public void SetDiffuseColor(double id0[])
    { SetDiffuseColor_8(id0); }

  private native double[] GetDiffuseColor_9();
  public double[] GetDiffuseColor()
    { return GetDiffuseColor_9(); }

  private native void SetSpecularColor_10(double id0,double id1,double id2);
  public void SetSpecularColor(double id0,double id1,double id2)
    { SetSpecularColor_10(id0,id1,id2); }

  private native void SetSpecularColor_11(double id0[]);
  public void SetSpecularColor(double id0[])
    { SetSpecularColor_11(id0); }

  private native double[] GetSpecularColor_12();
  public double[] GetSpecularColor()
    { return GetSpecularColor_12(); }

  private native void SetColor_13(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_13(id0,id1,id2); }

  private native void SetColor_14(double id0[]);
  public void SetColor(double id0[])
    { SetColor_14(id0); }

  private native void SetPosition_15(double id0,double id1,double id2);
  public void SetPosition(double id0,double id1,double id2)
    { SetPosition_15(id0,id1,id2); }

  private native void SetPosition_16(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_16(id0); }

  private native double[] GetPosition_17();
  public double[] GetPosition()
    { return GetPosition_17(); }

  private native void SetFocalPoint_18(double id0,double id1,double id2);
  public void SetFocalPoint(double id0,double id1,double id2)
    { SetFocalPoint_18(id0,id1,id2); }

  private native void SetFocalPoint_19(double id0[]);
  public void SetFocalPoint(double id0[])
    { SetFocalPoint_19(id0); }

  private native double[] GetFocalPoint_20();
  public double[] GetFocalPoint()
    { return GetFocalPoint_20(); }

  private native void SetIntensity_21(double id0);
  public void SetIntensity(double id0)
    { SetIntensity_21(id0); }

  private native double GetIntensity_22();
  public double GetIntensity()
    { return GetIntensity_22(); }

  private native void SetSwitch_23(int id0);
  public void SetSwitch(int id0)
    { SetSwitch_23(id0); }

  private native int GetSwitch_24();
  public int GetSwitch()
    { return GetSwitch_24(); }

  private native void SwitchOn_25();
  public void SwitchOn()
    { SwitchOn_25(); }

  private native void SwitchOff_26();
  public void SwitchOff()
    { SwitchOff_26(); }

  private native void SetPositional_27(int id0);
  public void SetPositional(int id0)
    { SetPositional_27(id0); }

  private native int GetPositional_28();
  public int GetPositional()
    { return GetPositional_28(); }

  private native void PositionalOn_29();
  public void PositionalOn()
    { PositionalOn_29(); }

  private native void PositionalOff_30();
  public void PositionalOff()
    { PositionalOff_30(); }

  private native void SetExponent_31(double id0);
  public void SetExponent(double id0)
    { SetExponent_31(id0); }

  private native double GetExponentMinValue_32();
  public double GetExponentMinValue()
    { return GetExponentMinValue_32(); }

  private native double GetExponentMaxValue_33();
  public double GetExponentMaxValue()
    { return GetExponentMaxValue_33(); }

  private native double GetExponent_34();
  public double GetExponent()
    { return GetExponent_34(); }

  private native void SetConeAngle_35(double id0);
  public void SetConeAngle(double id0)
    { SetConeAngle_35(id0); }

  private native double GetConeAngle_36();
  public double GetConeAngle()
    { return GetConeAngle_36(); }

  private native void SetAttenuationValues_37(double id0,double id1,double id2);
  public void SetAttenuationValues(double id0,double id1,double id2)
    { SetAttenuationValues_37(id0,id1,id2); }

  private native void SetAttenuationValues_38(double id0[]);
  public void SetAttenuationValues(double id0[])
    { SetAttenuationValues_38(id0); }

  private native double[] GetAttenuationValues_39();
  public double[] GetAttenuationValues()
    { return GetAttenuationValues_39(); }

  private native void SetTransformMatrix_40(vtkMatrix4x4 id0);
  public void SetTransformMatrix(vtkMatrix4x4 id0)
    { SetTransformMatrix_40(id0); }

  private native long GetTransformMatrix_41();
  public vtkMatrix4x4 GetTransformMatrix() {
    long temp = GetTransformMatrix_41();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetTransformedPosition_42(double id0[]);
  public void GetTransformedPosition(double id0[])
    { GetTransformedPosition_42(id0); }

  private native double[] GetTransformedPosition_43();
  public double[] GetTransformedPosition()
    { return GetTransformedPosition_43(); }

  private native void GetTransformedFocalPoint_44(double id0[]);
  public void GetTransformedFocalPoint(double id0[])
    { GetTransformedFocalPoint_44(id0); }

  private native double[] GetTransformedFocalPoint_45();
  public double[] GetTransformedFocalPoint()
    { return GetTransformedFocalPoint_45(); }

  private native void SetDirectionAngle_46(double id0,double id1);
  public void SetDirectionAngle(double id0,double id1)
    { SetDirectionAngle_46(id0,id1); }

  private native void SetDirectionAngle_47(double id0[]);
  public void SetDirectionAngle(double id0[])
    { SetDirectionAngle_47(id0); }

  private native void DeepCopy_48(vtkLight id0);
  public void DeepCopy(vtkLight id0)
    { DeepCopy_48(id0); }

  private native void SetLightType_49(int id0);
  public void SetLightType(int id0)
    { SetLightType_49(id0); }

  private native int GetLightType_50();
  public int GetLightType()
    { return GetLightType_50(); }

  private native void SetLightTypeToHeadlight_51();
  public void SetLightTypeToHeadlight()
    { SetLightTypeToHeadlight_51(); }

  private native void SetLightTypeToSceneLight_52();
  public void SetLightTypeToSceneLight()
    { SetLightTypeToSceneLight_52(); }

  private native void SetLightTypeToCameraLight_53();
  public void SetLightTypeToCameraLight()
    { SetLightTypeToCameraLight_53(); }

  private native int LightTypeIsHeadlight_54();
  public int LightTypeIsHeadlight()
    { return LightTypeIsHeadlight_54(); }

  private native int LightTypeIsSceneLight_55();
  public int LightTypeIsSceneLight()
    { return LightTypeIsSceneLight_55(); }

  private native int LightTypeIsCameraLight_56();
  public int LightTypeIsCameraLight()
    { return LightTypeIsCameraLight_56(); }

  private native void SetShadowAttenuation_57(double id0);
  public void SetShadowAttenuation(double id0)
    { SetShadowAttenuation_57(id0); }

  private native double GetShadowAttenuation_58();
  public double GetShadowAttenuation()
    { return GetShadowAttenuation_58(); }

  public vtkLight() { super(); }

  public vtkLight(long id) { super(id); }
  public native long   VTKInit();

}
